/***
 * Jonathan: an Open Distributed Processing Environment 
 * Copyright (C) 1999 France Telecom R&D
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Release: 2.0
 *
 * Contact: jonathan@objectweb.org
 *
 * Author: Bruno Dumant
 * 
 */

package org.objectweb.jonathan.model;

/**
 * A Binder is a naming context that not only manages names, but can also give
 * access to the object referenced by a name it manages. "Giving access" to 
 * a referenced object may be implemented in very different ways, such as setting
 * up an access path to the object (in ODP terminology, creating a binding object), 
 * causing the referenced object to move to make it accessible, creating a local 
 * replica of the object, etc. Examples of binders include:
 * <ul>
 * <li> <i>Object adapters</i>: An object adapter is a specific binder, responsible
 *      for the identification and activation of objects in a given address space;
 *      Object adapters may be used to simply multiplex several objects on a given
 *      network connection, but also to provide properties such as persistence, 
 *      or different activation policies.
 * <li> <i>ORBs</i>: the essential role of an Object Request Broker, is to 
 *      provide a remote access to objects; ORBs are thus specialized binders, 
 *      managing distribution-aware names, and providing the means to 
 *      {@link #bind(name) bind} these names.
 * </ul>
 */
public interface binder extends naming_context {

   /**
    * The <tt>bind</tt> operation is used to, given a name, give access to the
    * object interface it designates.
    * A <tt>bind</tt>
    * operation takes a name as parameter and returns an object representing the
    * object identified by the specified name. In some cases, it may be the
    * identified object itself, but usually it is a surrogate or proxy, giving
    * access to the identified object in a transparent way.
    * <p>
    * The <tt>bind</tt> operation may be borne directly by the name to which it
    * is applied, and/or require additional parameters (e.g., to specify quality
    * of service).
    */
   public Object bind(name name);
}



