/***
 * Jonathan: an Open Distributed Processing Environment 
 * Copyright (C) 1999 France Telecom R&D
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Release: 2.0
 *
 * Contact: jonathan@objectweb.org
 *
 * Author: Bruno Dumant
 * 
 */

package org.objectweb.jonathan.model;

/** 
 * A <i>domain</i> is a distributed naming context.
 * When identifiers are transmitted from one address space to another, they
 * are marshalled on one side (usually in a stub) and unmarshalled on the other
 * side (usually in a skeleton). However, the encoding of an identifier is not
 * sufficient to decode it: the knowledge of the naming context that created (and 
 * provided its encoding) is also necessary.
 * <p>
 * The simplest way to achieve this is to associate a binding with one specific 
 * naming context, that will encode and decode the identifiers. However, if 
 * multiple protocols need to be supported and cohabit, that naming context must
 * not be related to one specific protocol, but instead be able to accomodate 
 * several.
 * <p>
 * A <i>domain</i> is used for that purpose: it is able to identify other 
 * naming contexts (e.g., specific ORBs), and to wrap their identifiers into its 
 * own identifiers. Even if it is not expressed in the same terms, it is the 
 * solution adopted by the CORBA specification: when IIOP is used, the object 
 * references passed as arguments are marshalled as IORs that contain several 
 * protocol profiles distinguished by an integer id. In the case of CORBA, the 
 * association between an integer and a protocol, e.g., 0 and IIOP, is static. 
 */
public interface domain extends naming_context {
}



